public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
From: Matt Domsch <Matt_Domsch@dell.com>
To: akpm@osdl.org
Cc: fcusack@fcusack.org, linux-kernel@vger.kernel.org,
	pptpclient-devel@lists.sourceforge.net
Subject: [PATCH 2.6.13-rc6-mm2] ppp_mppe: author email change
Date: Mon, 29 Aug 2005 22:18:30 -0500	[thread overview]
Message-ID: <20050830031830.GA12041@lists.us.dell.com> (raw)

Frank Cusack, primary author of the ppp_mppe kernel module, is no
longer at Google.  This updates his email address in the module, as
agreed to by Frank privately.

 ppp_mppe.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

Signed-off-by: Matt Domsch <Matt_Domsch@dell.com>

-- 
Matt Domsch
Software Architect
Dell Linux Solutions linux.dell.com & www.dell.com/linux
Linux on Dell mailing lists @ http://lists.us.dell.com

diff -urNp --exclude-from=/home/mdomsch/excludes --minimal linux-2.6.13-rc6-mm2.orig/drivers/net/ppp_mppe.c linux-2.6.13-rc6-mm2/drivers/net/ppp_mppe.c
--- linux-2.6.13-rc6-mm2.orig/drivers/net/ppp_mppe.c	Mon Aug 29 22:08:58 2005
+++ linux-2.6.13-rc6-mm2/drivers/net/ppp_mppe.c	Mon Aug 29 22:10:23 2005
@@ -2,7 +2,7 @@
  * ppp_mppe.c - interface MPPE to the PPP code.
  * This version is for use with Linux kernel 2.6.14+
  *
  * By Frank Cusack <frank@google.com>.
  * Copyright (c) 2002,2003,2004 Google, Inc.
  * All rights reserved.
  *
@@ -59,7 +59,7 @@
 
 #include "ppp_mppe.h"
 
-MODULE_AUTHOR("Frank Cusack <frank@google.com>");
+MODULE_AUTHOR("Frank Cusack <fcusack@fcusack.com>");
 MODULE_DESCRIPTION("Point-to-Point Protocol Microsoft Point-to-Point Encryption support");
 MODULE_LICENSE("Dual BSD/GPL");
 MODULE_ALIAS("ppp-compress-" __stringify(CI_MPPE));
@@ -2,7 +2,7 @@
  * This version is for use with Linux kernel 2.6.14+
  *
- * By Frank Cusack <frank@google.com>.
+ * By Frank Cusack <fcusack@fcusack.com>.
  * Copyright (c) 2002,2003,2004 Google, Inc.
  * All rights reserved.

                 reply	other threads:[~2005-08-30  3:18 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20050830031830.GA12041@lists.us.dell.com \
    --to=matt_domsch@dell.com \
    --cc=akpm@osdl.org \
    --cc=fcusack@fcusack.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=pptpclient-devel@lists.sourceforge.net \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox